<?php
error_reporting(E_ALL ^ E_NOTICE);

header("Access-Control-Allow-Methods: GET, POST, PUT, DELETE");
header("Content-Type: application/json; charset=utf-8");

include_once '../conexion.php';
include_once '../clases/TokenValidator.php';

$usuarioId = TokenValidator::validar($conn);

$bodyRequest = file_get_contents("php://input");
$datos = json_decode($bodyRequest, true);

try {
    if (!isset($datos[0], $datos[1], $datos[2])) {
        echo json_encode([], JSON_UNESCAPED_UNICODE);
        exit;
    }

    $empresa_id  = (int)$datos[0];
    $sucursal_id = (int)$datos[1];
    $direccion   = trim((string)$datos[2]);

    if ($direccion === '') {
        echo json_encode([], JSON_UNESCAPED_UNICODE);
        exit;
    }

    // ✅ nombre correcto de la función
    $stmt = $conn->prepare("SELECT * FROM public.verifica_direccion(:empresa_id, :sucursal_id, :direccion)");

    $stmt->bindValue(':empresa_id', $empresa_id, PDO::PARAM_INT);
    $stmt->bindValue(':sucursal_id', $sucursal_id, PDO::PARAM_INT);
    $stmt->bindValue(':direccion', $direccion, PDO::PARAM_STR);

    $stmt->execute();
    $rows = $stmt->fetchAll(PDO::FETCH_ASSOC);

    echo json_encode($rows, JSON_UNESCAPED_UNICODE);

} catch (Exception $e) {
    // ⚠️ para que Java no reviente por objeto {error:...}
    echo json_encode([], JSON_UNESCAPED_UNICODE);
}
?>
