<?php
error_reporting(E_ALL & ~E_NOTICE);

header("Access-Control-Allow-Methods: GET, POST, PUT, DELETE");
header("Content-Type: application/json; charset=utf-8");

include_once '../conexion.php';
include_once '../clases/TokenValidator.php';

$usuarioId = TokenValidator::validar($conn);

try {
    $bodyRequest = file_get_contents("php://input");
    $datos = json_decode($bodyRequest, true);

    if (!is_array($datos) || count($datos) < 6) {
        throw new Exception("Parámetros inválidos. Se requieren 6 valores.");
    }

    $sql = "SELECT * FROM public.informe_planilla_reparto(:empresa_id, :sucursal_id, :fecha_ini, :fecha_fin, :vendedor_id, :zona_id)";
    $stmt = $conn->prepare($sql);

    $stmt->bindValue(':empresa_id',  (int)$datos[0], PDO::PARAM_INT);
    $stmt->bindValue(':sucursal_id', (int)$datos[1], PDO::PARAM_INT);
    $stmt->bindValue(':fecha_ini',   $datos[2], PDO::PARAM_STR);
    $stmt->bindValue(':fecha_fin',   $datos[3], PDO::PARAM_STR);
    $stmt->bindValue(':vendedor_id', (int)$datos[4], PDO::PARAM_INT);
    $stmt->bindValue(':zona_id',     (int)$datos[5], PDO::PARAM_INT);

    $stmt->execute();
    $rows = $stmt->fetchAll(PDO::FETCH_ASSOC);

    echo json_encode($rows, JSON_UNESCAPED_UNICODE);

} catch (Exception $e) {
    http_response_code(500);
    echo json_encode([
        "error" => "Error: " . $e->getMessage()
    ], JSON_UNESCAPED_UNICODE);
} finally {
    unset($stmt);
    $conn = null;
}
?>