<?php
/*
 * Copyright 2014 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

namespace Google\Service\Dialogflow;

class GoogleCloudDialogflowV2ToolCall extends \Google\Model
{
  /**
   * @var string
   */
  public $action;
  /**
   * @var string
   */
  public $answerRecord;
  /**
   * @var string
   */
  public $createTime;
  /**
   * @var array[]
   */
  public $inputParameters;
  /**
   * @var string
   */
  public $state;
  /**
   * @var string
   */
  public $tool;
  /**
   * @var string
   */
  public $toolDisplayDetails;
  /**
   * @var string
   */
  public $toolDisplayName;

  /**
   * @param string
   */
  public function setAction($action)
  {
    $this->action = $action;
  }
  /**
   * @return string
   */
  public function getAction()
  {
    return $this->action;
  }
  /**
   * @param string
   */
  public function setAnswerRecord($answerRecord)
  {
    $this->answerRecord = $answerRecord;
  }
  /**
   * @return string
   */
  public function getAnswerRecord()
  {
    return $this->answerRecord;
  }
  /**
   * @param string
   */
  public function setCreateTime($createTime)
  {
    $this->createTime = $createTime;
  }
  /**
   * @return string
   */
  public function getCreateTime()
  {
    return $this->createTime;
  }
  /**
   * @param array[]
   */
  public function setInputParameters($inputParameters)
  {
    $this->inputParameters = $inputParameters;
  }
  /**
   * @return array[]
   */
  public function getInputParameters()
  {
    return $this->inputParameters;
  }
  /**
   * @param string
   */
  public function setState($state)
  {
    $this->state = $state;
  }
  /**
   * @return string
   */
  public function getState()
  {
    return $this->state;
  }
  /**
   * @param string
   */
  public function setTool($tool)
  {
    $this->tool = $tool;
  }
  /**
   * @return string
   */
  public function getTool()
  {
    return $this->tool;
  }
  /**
   * @param string
   */
  public function setToolDisplayDetails($toolDisplayDetails)
  {
    $this->toolDisplayDetails = $toolDisplayDetails;
  }
  /**
   * @return string
   */
  public function getToolDisplayDetails()
  {
    return $this->toolDisplayDetails;
  }
  /**
   * @param string
   */
  public function setToolDisplayName($toolDisplayName)
  {
    $this->toolDisplayName = $toolDisplayName;
  }
  /**
   * @return string
   */
  public function getToolDisplayName()
  {
    return $this->toolDisplayName;
  }
}

// Adding a class alias for backwards compatibility with the previous class name.
class_alias(GoogleCloudDialogflowV2ToolCall::class, 'Google_Service_Dialogflow_GoogleCloudDialogflowV2ToolCall');
