<?php
/*
 * Copyright 2014 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

namespace Google\Service\AndroidProvisioningPartner;

class PartnerUnclaim extends \Google\Model
{
  /**
   * @var string
   */
  public $deviceId;
  protected $deviceIdentifierType = DeviceIdentifier::class;
  protected $deviceIdentifierDataType = '';
  /**
   * @var string
   */
  public $sectionType;
  /**
   * @var int
   */
  public $vacationModeDays;
  /**
   * @var string
   */
  public $vacationModeExpireTime;

  /**
   * @param string
   */
  public function setDeviceId($deviceId)
  {
    $this->deviceId = $deviceId;
  }
  /**
   * @return string
   */
  public function getDeviceId()
  {
    return $this->deviceId;
  }
  /**
   * @param DeviceIdentifier
   */
  public function setDeviceIdentifier(DeviceIdentifier $deviceIdentifier)
  {
    $this->deviceIdentifier = $deviceIdentifier;
  }
  /**
   * @return DeviceIdentifier
   */
  public function getDeviceIdentifier()
  {
    return $this->deviceIdentifier;
  }
  /**
   * @param string
   */
  public function setSectionType($sectionType)
  {
    $this->sectionType = $sectionType;
  }
  /**
   * @return string
   */
  public function getSectionType()
  {
    return $this->sectionType;
  }
  /**
   * @param int
   */
  public function setVacationModeDays($vacationModeDays)
  {
    $this->vacationModeDays = $vacationModeDays;
  }
  /**
   * @return int
   */
  public function getVacationModeDays()
  {
    return $this->vacationModeDays;
  }
  /**
   * @param string
   */
  public function setVacationModeExpireTime($vacationModeExpireTime)
  {
    $this->vacationModeExpireTime = $vacationModeExpireTime;
  }
  /**
   * @return string
   */
  public function getVacationModeExpireTime()
  {
    return $this->vacationModeExpireTime;
  }
}

// Adding a class alias for backwards compatibility with the previous class name.
class_alias(PartnerUnclaim::class, 'Google_Service_AndroidProvisioningPartner_PartnerUnclaim');
