<?php
/*
 * Copyright 2014 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

namespace Google\Service\Books;

class Layersummary extends \Google\Collection
{
  protected $collection_key = 'annotationTypes';
  /**
   * @var int
   */
  public $annotationCount;
  /**
   * @var string[]
   */
  public $annotationTypes;
  /**
   * @var string
   */
  public $annotationsDataLink;
  /**
   * @var string
   */
  public $annotationsLink;
  /**
   * @var string
   */
  public $contentVersion;
  /**
   * @var int
   */
  public $dataCount;
  /**
   * @var string
   */
  public $id;
  /**
   * @var string
   */
  public $kind;
  /**
   * @var string
   */
  public $layerId;
  /**
   * @var string
   */
  public $selfLink;
  /**
   * @var string
   */
  public $updated;
  /**
   * @var string
   */
  public $volumeAnnotationsVersion;
  /**
   * @var string
   */
  public $volumeId;

  /**
   * @param int
   */
  public function setAnnotationCount($annotationCount)
  {
    $this->annotationCount = $annotationCount;
  }
  /**
   * @return int
   */
  public function getAnnotationCount()
  {
    return $this->annotationCount;
  }
  /**
   * @param string[]
   */
  public function setAnnotationTypes($annotationTypes)
  {
    $this->annotationTypes = $annotationTypes;
  }
  /**
   * @return string[]
   */
  public function getAnnotationTypes()
  {
    return $this->annotationTypes;
  }
  /**
   * @param string
   */
  public function setAnnotationsDataLink($annotationsDataLink)
  {
    $this->annotationsDataLink = $annotationsDataLink;
  }
  /**
   * @return string
   */
  public function getAnnotationsDataLink()
  {
    return $this->annotationsDataLink;
  }
  /**
   * @param string
   */
  public function setAnnotationsLink($annotationsLink)
  {
    $this->annotationsLink = $annotationsLink;
  }
  /**
   * @return string
   */
  public function getAnnotationsLink()
  {
    return $this->annotationsLink;
  }
  /**
   * @param string
   */
  public function setContentVersion($contentVersion)
  {
    $this->contentVersion = $contentVersion;
  }
  /**
   * @return string
   */
  public function getContentVersion()
  {
    return $this->contentVersion;
  }
  /**
   * @param int
   */
  public function setDataCount($dataCount)
  {
    $this->dataCount = $dataCount;
  }
  /**
   * @return int
   */
  public function getDataCount()
  {
    return $this->dataCount;
  }
  /**
   * @param string
   */
  public function setId($id)
  {
    $this->id = $id;
  }
  /**
   * @return string
   */
  public function getId()
  {
    return $this->id;
  }
  /**
   * @param string
   */
  public function setKind($kind)
  {
    $this->kind = $kind;
  }
  /**
   * @return string
   */
  public function getKind()
  {
    return $this->kind;
  }
  /**
   * @param string
   */
  public function setLayerId($layerId)
  {
    $this->layerId = $layerId;
  }
  /**
   * @return string
   */
  public function getLayerId()
  {
    return $this->layerId;
  }
  /**
   * @param string
   */
  public function setSelfLink($selfLink)
  {
    $this->selfLink = $selfLink;
  }
  /**
   * @return string
   */
  public function getSelfLink()
  {
    return $this->selfLink;
  }
  /**
   * @param string
   */
  public function setUpdated($updated)
  {
    $this->updated = $updated;
  }
  /**
   * @return string
   */
  public function getUpdated()
  {
    return $this->updated;
  }
  /**
   * @param string
   */
  public function setVolumeAnnotationsVersion($volumeAnnotationsVersion)
  {
    $this->volumeAnnotationsVersion = $volumeAnnotationsVersion;
  }
  /**
   * @return string
   */
  public function getVolumeAnnotationsVersion()
  {
    return $this->volumeAnnotationsVersion;
  }
  /**
   * @param string
   */
  public function setVolumeId($volumeId)
  {
    $this->volumeId = $volumeId;
  }
  /**
   * @return string
   */
  public function getVolumeId()
  {
    return $this->volumeId;
  }
}

// Adding a class alias for backwards compatibility with the previous class name.
class_alias(Layersummary::class, 'Google_Service_Books_Layersummary');
