<?php
/*
 * Copyright 2014 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

namespace Google\Service\CertificateManager;

class AuthorizationAttemptInfo extends \Google\Model
{
  /**
   * @var string
   */
  public $attemptTime;
  /**
   * @var string
   */
  public $details;
  /**
   * @var string
   */
  public $domain;
  /**
   * @var string
   */
  public $failureReason;
  /**
   * @var string
   */
  public $state;
  protected $troubleshootingType = Troubleshooting::class;
  protected $troubleshootingDataType = '';

  /**
   * @param string
   */
  public function setAttemptTime($attemptTime)
  {
    $this->attemptTime = $attemptTime;
  }
  /**
   * @return string
   */
  public function getAttemptTime()
  {
    return $this->attemptTime;
  }
  /**
   * @param string
   */
  public function setDetails($details)
  {
    $this->details = $details;
  }
  /**
   * @return string
   */
  public function getDetails()
  {
    return $this->details;
  }
  /**
   * @param string
   */
  public function setDomain($domain)
  {
    $this->domain = $domain;
  }
  /**
   * @return string
   */
  public function getDomain()
  {
    return $this->domain;
  }
  /**
   * @param string
   */
  public function setFailureReason($failureReason)
  {
    $this->failureReason = $failureReason;
  }
  /**
   * @return string
   */
  public function getFailureReason()
  {
    return $this->failureReason;
  }
  /**
   * @param string
   */
  public function setState($state)
  {
    $this->state = $state;
  }
  /**
   * @return string
   */
  public function getState()
  {
    return $this->state;
  }
  /**
   * @param Troubleshooting
   */
  public function setTroubleshooting(Troubleshooting $troubleshooting)
  {
    $this->troubleshooting = $troubleshooting;
  }
  /**
   * @return Troubleshooting
   */
  public function getTroubleshooting()
  {
    return $this->troubleshooting;
  }
}

// Adding a class alias for backwards compatibility with the previous class name.
class_alias(AuthorizationAttemptInfo::class, 'Google_Service_CertificateManager_AuthorizationAttemptInfo');
