<?php
/*
 * Copyright 2014 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

namespace Google\Service\CloudSearch;

class AppsDynamiteSharedFindDocumentSuggestion extends \Google\Collection
{
  protected $collection_key = 'documentSuggestions';
  protected $documentSuggestionsType = AppsDynamiteSharedDocument::class;
  protected $documentSuggestionsDataType = 'array';
  /**
   * @var bool
   */
  public $showActionButtons;

  /**
   * @param AppsDynamiteSharedDocument[]
   */
  public function setDocumentSuggestions($documentSuggestions)
  {
    $this->documentSuggestions = $documentSuggestions;
  }
  /**
   * @return AppsDynamiteSharedDocument[]
   */
  public function getDocumentSuggestions()
  {
    return $this->documentSuggestions;
  }
  /**
   * @param bool
   */
  public function setShowActionButtons($showActionButtons)
  {
    $this->showActionButtons = $showActionButtons;
  }
  /**
   * @return bool
   */
  public function getShowActionButtons()
  {
    return $this->showActionButtons;
  }
}

// Adding a class alias for backwards compatibility with the previous class name.
class_alias(AppsDynamiteSharedFindDocumentSuggestion::class, 'Google_Service_CloudSearch_AppsDynamiteSharedFindDocumentSuggestion');
