<?php
error_reporting(E_ALL ^ E_NOTICE);

// Permite la ejecución de los métodos
header("Access-Control-Allow-Methods: GET, POST, PUT, DELETE");
header("Content-Type: application/json; charset=utf-8");

// Se incluye el archivo que contiene la conexión a PostgreSQL
include_once '../conexion.php';
include_once '../clases/TokenValidator.php';

// Llama la validación antes de cualquier consulta
$usuarioId = TokenValidator::validar($conn);

$bodyRequest = file_get_contents("php://input");
// Decodifica el cuerpo de la solicitud y lo guarda en un array de PHP
$datos = json_decode($bodyRequest, true);

$rows = array();

try {
    // Preparar la consulta SQL
    $sql = "SELECT S.* FROM sucursales AS S 
            INNER JOIN sede_usuario AS SU ON S.id = SU.sucursal_id
            WHERE S.empresa_id = :empresa_id 
            AND SU.usuario_id = :usuario_id 
            AND S.nombre = :nombre 
            AND S.activo = 1 
            ORDER BY S.nombre";
    $stmt = $conn->prepare($sql);
    $stmt->bindValue(':empresa_id', $datos[0], PDO::PARAM_INT);
    $stmt->bindValue(':usuario_id', $datos[1], PDO::PARAM_INT);
    $stmt->bindValue(':nombre', $datos[2], PDO::PARAM_STR);
    $stmt->execute();

    // Obtener el resultado de la consulta
    $rows = $stmt->fetchAll(PDO::FETCH_ASSOC);

    if (empty($rows)) {
        // No se encontraron registros
        print_json([]);
    }
} catch (PDOException $e) {
    error_response("ERROR: Could not able to execute the query. " . $e->getMessage());
}

// Cerrar la conexión a la base de datos
$conn = null;

// Imprimir la respuesta en formato JSON
print_json($rows);

function print_json($data) {
    echo json_encode($data, JSON_UNESCAPED_UNICODE);

    switch (json_last_error()) {
        case JSON_ERROR_NONE:
            break;
        case JSON_ERROR_DEPTH:
            error_response('Maximum stack depth exceeded');
            break;
        case JSON_ERROR_STATE_MISMATCH:
            error_response('Underflow or the modes mismatch');
            break;
        case JSON_ERROR_CTRL_CHAR:
            error_response('Unexpected control character found');
            break;
        case JSON_ERROR_SYNTAX:
            error_response('Syntax error, malformed JSON');
            break;
        case JSON_ERROR_UTF8:
            error_response('Malformed UTF-8 characters, possibly incorrectly encoded');
            break;
        default:
            error_response('Unknown error');
            break;
    }
}

function error_response($message) {
    http_response_code(500);
    echo json_encode(['error' => $message], JSON_UNESCAPED_UNICODE);
    exit();
}
?>