<?php
/*
 * Copyright 2014 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

namespace Google\Service\Contactcenterinsights;

class GoogleCloudContactcenterinsightsV1alpha1IssueModelResult extends \Google\Collection
{
  protected $collection_key = 'issues';
  /**
   * @var string
   */
  public $issueModel;
  protected $issuesType = GoogleCloudContactcenterinsightsV1alpha1IssueAssignment::class;
  protected $issuesDataType = 'array';

  /**
   * @param string
   */
  public function setIssueModel($issueModel)
  {
    $this->issueModel = $issueModel;
  }
  /**
   * @return string
   */
  public function getIssueModel()
  {
    return $this->issueModel;
  }
  /**
   * @param GoogleCloudContactcenterinsightsV1alpha1IssueAssignment[]
   */
  public function setIssues($issues)
  {
    $this->issues = $issues;
  }
  /**
   * @return GoogleCloudContactcenterinsightsV1alpha1IssueAssignment[]
   */
  public function getIssues()
  {
    return $this->issues;
  }
}

// Adding a class alias for backwards compatibility with the previous class name.
class_alias(GoogleCloudContactcenterinsightsV1alpha1IssueModelResult::class, 'Google_Service_Contactcenterinsights_GoogleCloudContactcenterinsightsV1alpha1IssueModelResult');
