<?php
/*
 * Copyright 2014 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

namespace Google\Service\AndroidPublisher;

class SubscriptionItemPriceChangeDetails extends \Google\Model
{
  /**
   * @var string
   */
  public $expectedNewPriceChargeTime;
  protected $newPriceType = Money::class;
  protected $newPriceDataType = '';
  /**
   * @var string
   */
  public $priceChangeMode;
  /**
   * @var string
   */
  public $priceChangeState;

  /**
   * @param string
   */
  public function setExpectedNewPriceChargeTime($expectedNewPriceChargeTime)
  {
    $this->expectedNewPriceChargeTime = $expectedNewPriceChargeTime;
  }
  /**
   * @return string
   */
  public function getExpectedNewPriceChargeTime()
  {
    return $this->expectedNewPriceChargeTime;
  }
  /**
   * @param Money
   */
  public function setNewPrice(Money $newPrice)
  {
    $this->newPrice = $newPrice;
  }
  /**
   * @return Money
   */
  public function getNewPrice()
  {
    return $this->newPrice;
  }
  /**
   * @param string
   */
  public function setPriceChangeMode($priceChangeMode)
  {
    $this->priceChangeMode = $priceChangeMode;
  }
  /**
   * @return string
   */
  public function getPriceChangeMode()
  {
    return $this->priceChangeMode;
  }
  /**
   * @param string
   */
  public function setPriceChangeState($priceChangeState)
  {
    $this->priceChangeState = $priceChangeState;
  }
  /**
   * @return string
   */
  public function getPriceChangeState()
  {
    return $this->priceChangeState;
  }
}

// Adding a class alias for backwards compatibility with the previous class name.
class_alias(SubscriptionItemPriceChangeDetails::class, 'Google_Service_AndroidPublisher_SubscriptionItemPriceChangeDetails');
