
<?php
error_reporting(E_ALL);

header("Access-Control-Allow-Methods: POST, PUT, GET, DELETE, OPTIONS");
header("Access-Control-Allow-Headers: Content-Type");
header("Content-Type: application/json; charset=utf-8");

include_once '../conexion.php';
include_once '../clases/TokenValidator.php';

// Llama la validación antes de cualquier consulta
$usuarioId = TokenValidator::validar($conn);

try {
    $bodyRequest = file_get_contents("php://input");
    $datos = json_decode($bodyRequest, true);

    if (!is_array($datos) || count($datos) < 4) {
        throw new Exception("Parámetros incompletos. Se requieren 4 datos.");
    }

    // Llamada a la función PostgreSQL
    $sql = "SELECT * FROM im_marca(:nombre, :empresa_id, :id_marca, :estado) AS id_marca";
    $stmt = $conn->prepare($sql);

    $stmt->bindValue(':nombre', $datos[0], PDO::PARAM_STR);
    $stmt->bindValue(':empresa_id', $datos[1], PDO::PARAM_INT);
    $stmt->bindValue(':id_marca', $datos[2], PDO::PARAM_INT);
    $stmt->bindValue(':estado', $datos[3], PDO::PARAM_STR);

    $stmt->execute();
    $result = $stmt->fetch(PDO::FETCH_ASSOC);

    $respuesta = [];

    if ($datos[3] === "NUEVO") {
        if ($result && isset($result['id_marca']) && $result['id_marca'] > 0) {
            $respuesta = [
                "ESTADO" => "1",
                "ID" => $result['id_marca'],
                "MENSAJE" => "LA INFORMACIÓN SE GUARDÓ CORRECTAMENTE"
            ];
        } else {
            $respuesta = [
                "ESTADO" => "0",
                "ID" => "0",
                "MENSAJE" => "ERROR AL GUARDAR LA INFORMACIÓN"
            ];
        }
    } else {
        $respuesta = [
            "ESTADO" => "1",
            "ID" => strval($datos[2]),
            "MENSAJE" => "LA INFORMACIÓN SE ACTUALIZÓ CORRECTAMENTE"
        ];
    }

    echo json_encode($respuesta, JSON_UNESCAPED_UNICODE);

} catch (Exception $e) {
    http_response_code(500);
    echo json_encode([
        "ESTADO" => "0",
        "ID" => "0",
        "MENSAJE" => "ERROR: " . $e->getMessage()
    ], JSON_UNESCAPED_UNICODE);
} finally {
    $conn = null;
}