<?php
/*
 * Copyright 2014 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

namespace Google\Service\CloudAsset;

class AnalyzeIamPolicyResponse extends \Google\Collection
{
  protected $collection_key = 'serviceAccountImpersonationAnalysis';
  /**
   * @var bool
   */
  public $fullyExplored;
  protected $mainAnalysisType = IamPolicyAnalysis::class;
  protected $mainAnalysisDataType = '';
  protected $serviceAccountImpersonationAnalysisType = IamPolicyAnalysis::class;
  protected $serviceAccountImpersonationAnalysisDataType = 'array';

  /**
   * @param bool
   */
  public function setFullyExplored($fullyExplored)
  {
    $this->fullyExplored = $fullyExplored;
  }
  /**
   * @return bool
   */
  public function getFullyExplored()
  {
    return $this->fullyExplored;
  }
  /**
   * @param IamPolicyAnalysis
   */
  public function setMainAnalysis(IamPolicyAnalysis $mainAnalysis)
  {
    $this->mainAnalysis = $mainAnalysis;
  }
  /**
   * @return IamPolicyAnalysis
   */
  public function getMainAnalysis()
  {
    return $this->mainAnalysis;
  }
  /**
   * @param IamPolicyAnalysis[]
   */
  public function setServiceAccountImpersonationAnalysis($serviceAccountImpersonationAnalysis)
  {
    $this->serviceAccountImpersonationAnalysis = $serviceAccountImpersonationAnalysis;
  }
  /**
   * @return IamPolicyAnalysis[]
   */
  public function getServiceAccountImpersonationAnalysis()
  {
    return $this->serviceAccountImpersonationAnalysis;
  }
}

// Adding a class alias for backwards compatibility with the previous class name.
class_alias(AnalyzeIamPolicyResponse::class, 'Google_Service_CloudAsset_AnalyzeIamPolicyResponse');
