<?php
error_reporting(E_ALL ^ E_NOTICE);

header("Access-Control-Allow-Methods: GET, POST, PUT, DELETE");
header("Content-Type: application/json; charset=utf-8");

include_once '../conexion.php';
include_once '../clases/TokenValidator.php';

$usuarioId = TokenValidator::validar($conn);

$bodyRequest = file_get_contents("php://input");
$datos = json_decode($bodyRequest, true);

$rows = array();

try {

    if (!is_array($datos) || count($datos) < 1) {
        throw new Exception("Parámetros inválidos. Se requiere [empresa_id].");
    }

    $empresa_id = (int)$datos[0];

    // Obtener usuario de sesión
    $stmtUser = $conn->prepare("
        SELECT UPPER(TRIM(nombre)) AS nombre
        FROM usuarios
        WHERE id = :usuario_id
        LIMIT 1
    ");
    $stmtUser->bindValue(':usuario_id', $usuarioId, PDO::PARAM_INT);
    $stmtUser->execute();

    $usuarioSesion = $stmtUser->fetchColumn();

    if (!$usuarioSesion) {
        $usuarioSesion = '';
    }

    // Si el usuario de sesión es SOPORTE, ve todos.
    // Si no es SOPORTE, se oculta el usuario SOPORTE.
    $sql = "SELECT id, nombre_completo
            FROM usuarios
            WHERE empresa_id = :empresa_id
              AND activo = true
              AND (
                    :usuario_sesion = 'SOPORTE'
                    OR UPPER(TRIM(nombre)) <> 'SOPORTE'
                  )
            ORDER BY nombre_completo";

    $stmt = $conn->prepare($sql);
    $stmt->bindValue(':empresa_id', $empresa_id, PDO::PARAM_INT);
    $stmt->bindValue(':usuario_sesion', $usuarioSesion, PDO::PARAM_STR);
    $stmt->execute();

    $rows = $stmt->fetchAll(PDO::FETCH_ASSOC);

    array_unshift($rows, [
        'id' => 0,
        'nombre_completo' => 'SELECCIONA EMPLEADO'
    ]);

    print_json($rows);

} catch (Exception $e) {
    error_response("Error al ejecutar la consulta: " . $e->getMessage());
} finally {
    $conn = null;
}

function print_json($data) {
    echo json_encode($data, JSON_UNESCAPED_UNICODE);
    exit();
}

function error_response($message) {
    http_response_code(500);
    echo json_encode(['error' => $message], JSON_UNESCAPED_UNICODE);
    exit();
}
?>