<?php
error_reporting(E_ALL);

header("Access-Control-Allow-Methods: GET, POST, PUT, DELETE");
header("Content-Type: application/json; charset=utf-8");

include_once '../conexion.php';
include_once '../clases/TokenValidator.php';

// Llama la validación antes de cualquier consulta
$usuarioId = TokenValidator::validar($conn);

try {
    $bodyRequest = file_get_contents("php://input");
    $datos = json_decode($bodyRequest, true);

    if (!is_array($datos) || count($datos) < 3) {
        throw new Exception("Parámetros incompletos. Se esperan: empresa_id, sucursal_id, documento_identidad.");
    }

    $sql = "SELECT documento_identidad 
            FROM empleados 
            WHERE empresa_id = :empresa_id 
              AND sucursal_id = :sucursal_id 
              AND documento_identidad = :documento_identidad 
            LIMIT 1";

    $stmt = $conn->prepare($sql);
    $stmt->bindValue(':empresa_id', $datos[0], PDO::PARAM_INT);
    $stmt->bindValue(':sucursal_id', $datos[1], PDO::PARAM_INT);
    $stmt->bindValue(':documento_identidad', $datos[2], PDO::PARAM_STR);

    $stmt->execute();
    $rows = $stmt->fetchAll(PDO::FETCH_ASSOC);

    echo json_encode($rows ?: [], JSON_UNESCAPED_UNICODE);

} catch (Exception $e) {
    http_response_code(500);
    echo json_encode(['error' => 'ERROR: ' . $e->getMessage()], JSON_UNESCAPED_UNICODE);
} finally {
    $conn = null;
}
?>
