<?php
/*
 * Copyright 2014 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

namespace Google\Service\Container;

class ContainerdConfig extends \Google\Collection
{
  protected $collection_key = 'registryHosts';
  protected $privateRegistryAccessConfigType = PrivateRegistryAccessConfig::class;
  protected $privateRegistryAccessConfigDataType = '';
  protected $registryHostsType = RegistryHostConfig::class;
  protected $registryHostsDataType = 'array';
  protected $writableCgroupsType = WritableCgroups::class;
  protected $writableCgroupsDataType = '';

  /**
   * @param PrivateRegistryAccessConfig
   */
  public function setPrivateRegistryAccessConfig(PrivateRegistryAccessConfig $privateRegistryAccessConfig)
  {
    $this->privateRegistryAccessConfig = $privateRegistryAccessConfig;
  }
  /**
   * @return PrivateRegistryAccessConfig
   */
  public function getPrivateRegistryAccessConfig()
  {
    return $this->privateRegistryAccessConfig;
  }
  /**
   * @param RegistryHostConfig[]
   */
  public function setRegistryHosts($registryHosts)
  {
    $this->registryHosts = $registryHosts;
  }
  /**
   * @return RegistryHostConfig[]
   */
  public function getRegistryHosts()
  {
    return $this->registryHosts;
  }
  /**
   * @param WritableCgroups
   */
  public function setWritableCgroups(WritableCgroups $writableCgroups)
  {
    $this->writableCgroups = $writableCgroups;
  }
  /**
   * @return WritableCgroups
   */
  public function getWritableCgroups()
  {
    return $this->writableCgroups;
  }
}

// Adding a class alias for backwards compatibility with the previous class name.
class_alias(ContainerdConfig::class, 'Google_Service_Container_ContainerdConfig');
