<?php
/*
 * Copyright 2014 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

namespace Google\Service\Aiplatform;

class GoogleCloudAiplatformV1Fact extends \Google\Model
{
  protected $chunkType = GoogleCloudAiplatformV1RagChunk::class;
  protected $chunkDataType = '';
  /**
   * @var string
   */
  public $query;
  public $score;
  /**
   * @var string
   */
  public $summary;
  /**
   * @var string
   */
  public $title;
  /**
   * @var string
   */
  public $uri;
  public $vectorDistance;

  /**
   * @param GoogleCloudAiplatformV1RagChunk
   */
  public function setChunk(GoogleCloudAiplatformV1RagChunk $chunk)
  {
    $this->chunk = $chunk;
  }
  /**
   * @return GoogleCloudAiplatformV1RagChunk
   */
  public function getChunk()
  {
    return $this->chunk;
  }
  /**
   * @param string
   */
  public function setQuery($query)
  {
    $this->query = $query;
  }
  /**
   * @return string
   */
  public function getQuery()
  {
    return $this->query;
  }
  public function setScore($score)
  {
    $this->score = $score;
  }
  public function getScore()
  {
    return $this->score;
  }
  /**
   * @param string
   */
  public function setSummary($summary)
  {
    $this->summary = $summary;
  }
  /**
   * @return string
   */
  public function getSummary()
  {
    return $this->summary;
  }
  /**
   * @param string
   */
  public function setTitle($title)
  {
    $this->title = $title;
  }
  /**
   * @return string
   */
  public function getTitle()
  {
    return $this->title;
  }
  /**
   * @param string
   */
  public function setUri($uri)
  {
    $this->uri = $uri;
  }
  /**
   * @return string
   */
  public function getUri()
  {
    return $this->uri;
  }
  public function setVectorDistance($vectorDistance)
  {
    $this->vectorDistance = $vectorDistance;
  }
  public function getVectorDistance()
  {
    return $this->vectorDistance;
  }
}

// Adding a class alias for backwards compatibility with the previous class name.
class_alias(GoogleCloudAiplatformV1Fact::class, 'Google_Service_Aiplatform_GoogleCloudAiplatformV1Fact');
