<?php
/*
 * Copyright 2014 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

namespace Google\Service\CloudRetail;

class GoogleCloudRetailV2PanelInfo extends \Google\Collection
{
  protected $collection_key = 'productDetails';
  /**
   * @var string
   */
  public $attributionToken;
  /**
   * @var string
   */
  public $displayName;
  /**
   * @var string
   */
  public $panelId;
  /**
   * @var int
   */
  public $panelPosition;
  protected $productDetailsType = GoogleCloudRetailV2ProductDetail::class;
  protected $productDetailsDataType = 'array';
  /**
   * @var int
   */
  public $totalPanels;

  /**
   * @param string
   */
  public function setAttributionToken($attributionToken)
  {
    $this->attributionToken = $attributionToken;
  }
  /**
   * @return string
   */
  public function getAttributionToken()
  {
    return $this->attributionToken;
  }
  /**
   * @param string
   */
  public function setDisplayName($displayName)
  {
    $this->displayName = $displayName;
  }
  /**
   * @return string
   */
  public function getDisplayName()
  {
    return $this->displayName;
  }
  /**
   * @param string
   */
  public function setPanelId($panelId)
  {
    $this->panelId = $panelId;
  }
  /**
   * @return string
   */
  public function getPanelId()
  {
    return $this->panelId;
  }
  /**
   * @param int
   */
  public function setPanelPosition($panelPosition)
  {
    $this->panelPosition = $panelPosition;
  }
  /**
   * @return int
   */
  public function getPanelPosition()
  {
    return $this->panelPosition;
  }
  /**
   * @param GoogleCloudRetailV2ProductDetail[]
   */
  public function setProductDetails($productDetails)
  {
    $this->productDetails = $productDetails;
  }
  /**
   * @return GoogleCloudRetailV2ProductDetail[]
   */
  public function getProductDetails()
  {
    return $this->productDetails;
  }
  /**
   * @param int
   */
  public function setTotalPanels($totalPanels)
  {
    $this->totalPanels = $totalPanels;
  }
  /**
   * @return int
   */
  public function getTotalPanels()
  {
    return $this->totalPanels;
  }
}

// Adding a class alias for backwards compatibility with the previous class name.
class_alias(GoogleCloudRetailV2PanelInfo::class, 'Google_Service_CloudRetail_GoogleCloudRetailV2PanelInfo');
