<?php
/*
 * Copyright 2014 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

namespace Google\Service\CloudDebugger;

class Variable extends \Google\Collection
{
  protected $collection_key = 'members';
  protected $membersType = Variable::class;
  protected $membersDataType = 'array';
  /**
   * @var string
   */
  public $name;
  protected $statusType = StatusMessage::class;
  protected $statusDataType = '';
  /**
   * @var string
   */
  public $type;
  /**
   * @var string
   */
  public $value;
  /**
   * @var int
   */
  public $varTableIndex;

  /**
   * @param Variable[]
   */
  public function setMembers($members)
  {
    $this->members = $members;
  }
  /**
   * @return Variable[]
   */
  public function getMembers()
  {
    return $this->members;
  }
  /**
   * @param string
   */
  public function setName($name)
  {
    $this->name = $name;
  }
  /**
   * @return string
   */
  public function getName()
  {
    return $this->name;
  }
  /**
   * @param StatusMessage
   */
  public function setStatus(StatusMessage $status)
  {
    $this->status = $status;
  }
  /**
   * @return StatusMessage
   */
  public function getStatus()
  {
    return $this->status;
  }
  /**
   * @param string
   */
  public function setType($type)
  {
    $this->type = $type;
  }
  /**
   * @return string
   */
  public function getType()
  {
    return $this->type;
  }
  /**
   * @param string
   */
  public function setValue($value)
  {
    $this->value = $value;
  }
  /**
   * @return string
   */
  public function getValue()
  {
    return $this->value;
  }
  /**
   * @param int
   */
  public function setVarTableIndex($varTableIndex)
  {
    $this->varTableIndex = $varTableIndex;
  }
  /**
   * @return int
   */
  public function getVarTableIndex()
  {
    return $this->varTableIndex;
  }
}

// Adding a class alias for backwards compatibility with the previous class name.
class_alias(Variable::class, 'Google_Service_CloudDebugger_Variable');
