<?php
/*
 * Copyright 2014 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

namespace Google\Service\Aiplatform;

class GoogleCloudAiplatformV1AutoraterConfig extends \Google\Model
{
  /**
   * @var string
   */
  public $autoraterModel;
  /**
   * @var bool
   */
  public $flipEnabled;
  protected $generationConfigType = GoogleCloudAiplatformV1GenerationConfig::class;
  protected $generationConfigDataType = '';
  /**
   * @var int
   */
  public $samplingCount;

  /**
   * @param string
   */
  public function setAutoraterModel($autoraterModel)
  {
    $this->autoraterModel = $autoraterModel;
  }
  /**
   * @return string
   */
  public function getAutoraterModel()
  {
    return $this->autoraterModel;
  }
  /**
   * @param bool
   */
  public function setFlipEnabled($flipEnabled)
  {
    $this->flipEnabled = $flipEnabled;
  }
  /**
   * @return bool
   */
  public function getFlipEnabled()
  {
    return $this->flipEnabled;
  }
  /**
   * @param GoogleCloudAiplatformV1GenerationConfig
   */
  public function setGenerationConfig(GoogleCloudAiplatformV1GenerationConfig $generationConfig)
  {
    $this->generationConfig = $generationConfig;
  }
  /**
   * @return GoogleCloudAiplatformV1GenerationConfig
   */
  public function getGenerationConfig()
  {
    return $this->generationConfig;
  }
  /**
   * @param int
   */
  public function setSamplingCount($samplingCount)
  {
    $this->samplingCount = $samplingCount;
  }
  /**
   * @return int
   */
  public function getSamplingCount()
  {
    return $this->samplingCount;
  }
}

// Adding a class alias for backwards compatibility with the previous class name.
class_alias(GoogleCloudAiplatformV1AutoraterConfig::class, 'Google_Service_Aiplatform_GoogleCloudAiplatformV1AutoraterConfig');
