<?php
error_reporting(E_ALL ^ E_NOTICE);

header("Access-Control-Allow-Methods: GET, POST, PUT, DELETE");
header("Content-Type: application/json; charset=utf-8");

include_once '../conexion.php';
include_once '../clases/TokenValidator.php';

$usuarioId = TokenValidator::validar($conn);

try {
    $bodyRequest = file_get_contents("php://input");
    $datos = json_decode($bodyRequest, true);

    if (
        !isset($datos[0], $datos[1], $datos[2], $datos[3], $datos[4]) ||
        !is_numeric($datos[0]) ||
        !is_numeric($datos[1]) ||
        !is_numeric($datos[2]) ||
        !is_bool($datos[3]) ||
        !is_numeric($datos[4])
    ) {
        throw new Exception("Parámetros inválidos.");
    }

    $empresaId = (int) $datos[0];
    $sucursalId = (int) $datos[1];
    $clienteId = (int) $datos[2];
    $esCancelado = (bool) $datos[3];
    $usuarioIdFiltro = (int) $datos[4];

    $sql = "SELECT * FROM public.listar_creditosxcob_movil(
        :empresa_id,
        :sucursal_id,
        :cliente_id,
        :es_cancelado,
        :usuario_id
    )";

    $stmt = $conn->prepare($sql);
    $stmt->bindValue(':empresa_id', $empresaId, PDO::PARAM_INT);
    $stmt->bindValue(':sucursal_id', $sucursalId, PDO::PARAM_INT);
    $stmt->bindValue(':cliente_id', $clienteId, PDO::PARAM_INT);
    $stmt->bindValue(':es_cancelado', $esCancelado, PDO::PARAM_BOOL);
    $stmt->bindValue(':usuario_id', $usuarioIdFiltro, PDO::PARAM_INT);

    $stmt->execute();

    $rows = $stmt->fetchAll(PDO::FETCH_ASSOC);

    echo json_encode($rows, JSON_UNESCAPED_UNICODE);

} catch (Exception $e) {
    http_response_code(500);
    echo json_encode([
        'error' => 'Error: ' . $e->getMessage()
    ], JSON_UNESCAPED_UNICODE);
} finally {
    $conn = null;
}
?>