<?php

error_reporting(E_ALL ^ E_NOTICE);
// Permite la conexion desde cualquier origen
header("Access-Control-Allow-Origin: *");
// Permite la ejecucion de los metodos
header("Access-Control-Allow-Methods: GET, POST, PUT, DELETE");
// Se incluye el archivo que contiene la clase generica
include_once '../conexion.php';

$bodyRequest = file_get_contents("php://input");

// Decodifica el cuerpo de la solicitud y lo guarda en un array de PHP
$datos = json_decode($bodyRequest, true);
    
    $sql="DELETE FROM categorias WHERE id=" . $datos['id'] . "";

    if ($result = mysqli_query($conn, $sql)) {
        $resultado = array();
        $resultado['ESTADO'] = "1";
        $resultado['MENSAJE'] = "LA INFORMACION ELIMINO CORRECTAMENTE";
    }else{
        $resultado = array();
        $resultado['ESTADO'] = "0";
        $resultado['MENSAJE'] = "ERROR AL ELIMINO INFORMACION: ".mysqli_error($conn);   
    }

print_json($resultado);

function print_json($data) {
    header("HTTP/1.1");
    header("Content-Type: application/json; charset=UTF-8");
    echo json_encode($data, JSON_PRETTY_PRINT);
}


?>